!-----------------------BEGIN NOTICE -- DO NOT EDIT-----------------------
! NASA Goddard Space Flight Center Land Information System (LIS) v7.1
!
! Copyright (c) 2015 United States Government as represented by the
! Administrator of the National Aeronautics and Space Administration.
! All Rights Reserved.
!-------------------------END NOTICE -- DO NOT EDIT-----------------------
!BOP
!
! !ROUTINE: timeinterp_petusgs
! \label{timeinterp_petusgs}
! 
! !REVISION HISTORY: 
!  20 Jan 2006:  Yudong Tian: Initial Implementation
!  10 Oct 2006:  Sujay Kumar: Switched to using ESMF_State for storing
!                              forcing data. 
!  10 Mar 2012:  K. Arsenault: Applied to USGS PET dataset
!  25 Oct 2013:  K. Arsenault: added PET USGS to LIS7
!
! !INTERFACE:
subroutine timeinterp_petusgs(n, findex )

! !USES:
  use ESMF
  use LIS_coreMod,        only : LIS_rc,LIS_domain
  use LIS_FORC_AttributesMod
  use LIS_metforcingMod,  only : LIS_FORC_State, LIS_forc
  use LIS_logMod,         only : LIS_verify
  use petusgs_forcingMod, only : petusgs_struc

  implicit none
! !ARGUMENTS: 
  integer, intent(in) :: n 
  integer, intent(in) :: findex
!
! !DESCRIPTION:
!  Temporally interpolates the forcing data to the current model 
!   timestep. 
!
!  Also, daily PET values are scaled up (i.e. multiplied) by a factor 
!   of 100 to preserve the precision, so here the read-in values are
!   divided by 100 to obtain actual PET summary.
!
!  The arguments are: 
!  \begin{description}
!  \item[n]
!   index of the nest
!  \end{description}
!
!EOP

   integer          :: t,index1

   integer          :: status
   type(ESMF_Field) :: petfield
!   type(ESMF_Field) :: rETfield
   real, pointer    :: pet(:)
!   real, pointer    :: rET(:)
    real,  allocatable :: ratio(:)

    allocate(ratio(LIS_rc%ntiles(n)))

! ----------------------------------------

    call ESMF_StateGet(LIS_FORC_State(n),trim(LIS_FORC_PET%varname(1)),petfield,&
          rc=status)
    call LIS_verify(status, 'Error: enable PET in forcing variables list')

!    call ESMF_StateGet(LIS_FORC_State(n),trim(LIS_FORC_RefET%varname(1)),rETfield,&
!          rc=status)
!    call LIS_verify(status, 'Error: enable RefET in forcing variables list')


    call ESMF_FieldGet(petfield,localDE=0,farrayptr=pet,rc=status)
    call LIS_verify(status)

!    call ESMF_FieldGet(retField,localDE=0,farrayptr=rET,rc=status)
!    call LIS_verify(status)

!------------------------------------------------------------------------

    do t=1,LIS_rc%ntiles(n)
       index1 = LIS_domain(n)%tile(t)%index

       if( LIS_forc(n,findex)%metdata2(1,index1) .ne. -1.0 ) &

       !- Convert scaled daily PET to actual values (precision: 0.01):
          pet(t) = LIS_forc(n,findex)%metdata2(1,index1) / 100.     

       !- Convert mm/day to rate with seconds:
          pet(t) = pet(t) / 86400.     ! mm/s

!       if (LIS_forc(n,findex)%metdata2(n,index1) .ne. -1.0) &
!        rET(t) = LIS_forc(n,findex)%metdata2(n,index1)

    enddo

    deallocate(ratio)

end subroutine timeinterp_petusgs
  
